@@ -203,6 +203,17 @@ class QainitHandler:
 
         logger.debug(json.dumps(r.json(), indent=2))
 
+    def force_update(self, qa_hash):
+        r = self._execute("POST", f"/api/v1/qa/shit-shoveler/force-update/{qa_hash}")
+        if r.status_code == 400:
+            logger.error("QA is not in a stale state")
+            return
+        if r.status_code == 500:
+            logger.error("Something went wrong")
+            return
+        logger.info("QA has been forced to update")
+        logger.debug(json.dumps(r.json(), indent=2))
+
     def _execute(self, request_method, api_endpoint, body=None):
         api_url = self.url + api_endpoint
         auth0_token = self._config.get_cache(f"{self.auth0_tenant}_auth0_token")
